@@ -1,4 +1,4 @@
-/* Copyright (c) 2002 Sam Trenholme
+/* Copyright (c) 2002-2006 Sam Trenholme
  *
  * TERMS
  *
@@ -83,7 +83,7 @@ compress_state *compress_init_state(js_string *uncompressed) {
     new->uncompressed = uncompressed;
 
     /* Initialize the values which allocate memory */
-    if((new->compressed = js_create(MAX_COMPRESSED_LEN + 3,1)) == 0) {
+    if((new->compressed = js_create(MAX_COMPRESSED_LEN + 4,1)) == 0) {
         js_dealloc(new);
 	return 0;
 	}
@@ -536,6 +536,11 @@ int compress_rddata(compress_state *state) {
             /* Text data fields */
             else if(subtype == RRSUB_TEXT) {
 	        int len;
+		if(state->uncompressed_offset >= 
+		   state->uncompressed->unit_count) {
+		    state->valid_state = 0;
+                    return JS_ERROR;
+                    }
                 len = *(state->uncompressed->string + 
 		        state->uncompressed_offset);
                 if(len < 0 || len > 256) {
@@ -647,7 +652,7 @@ int compress_get_uint16(compress_state *state) {
 	return JS_ERROR;
 	}
     state->uncompressed_offset += 2;
-    if(state->uncompressed_offset >= state->uncompressed->unit_count) {
+    if(state->uncompressed_offset > state->uncompressed->unit_count) {
         state->valid_state = 0;
 	return JS_ERROR;
 	}
@@ -812,6 +817,7 @@ int compress_get_header(compress_state *state) {
  */
 
 int compress_get_question(compress_state *state) {
+
     /* Sanity checks */
     if(state->valid_state != 1) {
         return JS_ERROR;
@@ -821,6 +827,10 @@ int compress_get_question(compress_state *state) {
 	return JS_ERROR;
 	}
 
+    if(state->number_answers == -2) { /* No questions nor answers */
+	return JS_SUCCESS;
+	}
+
     /* The domain name question */
     if(compress_dlabel(state) != JS_SUCCESS) {
         state->valid_state = 0;
