@@ -1,4 +1,4 @@
-/* Copyright (c) 2002 Sam Trenholme
+/* Copyright (c) 2002-2006 Sam Trenholme
  *
  * TERMS
  *
@@ -645,6 +645,13 @@ int email_2rfc1035(js_string *hostname) {
 
      /* Convert the at/dots in to hostname delimiters */
      seen = counter = 0;
+     /* Handle the special case of this being just a dot by itself */
+     if(hostname->unit_count == 2 && *(raw + 1) == '.') {
+	 hostname->unit_count = 1;
+	 *(hostname->string) = '\0';
+	 return JS_SUCCESS;
+	 }
+	 
      while(counter < 256 && counter < hostname->unit_count) {
          counter++;
          if(counter > hostname->unit_count) 
@@ -664,6 +671,12 @@ int email_2rfc1035(js_string *hostname) {
              break;
          } 
 
+     /* Handle the case of this string not having an @ in it by
+      * processing the string as one with just dots */ 
+     if(firstat) {
+	 return hname_2rfc1035_starwhitis(hostname,0);
+         }
+
      /* That last '0' for the dot after .com */
      if(counter < 256 && *(raw + counter) == '.')
          *(raw + counter) = 0;
@@ -954,3 +967,125 @@ int read_txt(js_string *in, js_string *out, int offset) {
     return out->unit_count;
     }
 
+/* This function is designed to make a packet which compresses to a size
+ * greater than 512 bytes smaller.  The input is an uncompressed DNS packet;
+ * the output is the same packet with the last DNS record removed from the
+ * packet.  As per RFC2181 §9, if we are removing a DNS record from the NS
+ * or AN section of a reply, the TC bit is not set.  Otherwise (as a 
+ * reasonable interpretation of the wishes in RFC2181 §9), we remove all DNS
+ * information except the header and mark the DNS packet truncated. 
+ *
+ * Input: A js_string object with a full uncompressed raw DNS packet.
+ * 
+ * Output: A point to the above js_string object on success; 0 on error */
+
+js_string *squeeze_to_fit(js_string *packet) {
+	q_header hdr;
+	int qd,an,ns,ar; /* counts of the various record types */
+	int qc,count;
+        int offset;
+	
+        if(read_hdr(packet,&hdr) == JS_ERROR) {
+		return 0;
+	}
+
+	qd = hdr.qdcount;
+	an = hdr.ancount;
+	ns = hdr.nscount;
+	ar = hdr.arcount;
+
+        /* If the packet is already marked truncated, we remove all records
+         * past the record and otherwise return it as is;
+	 * In the case of there being no ns nor ar records, we do the same
+         * thing */
+
+	if(hdr.tc == 1 || (ns == 0 && ar == 0)) {
+		hdr.tc = 1;
+		hdr.qdcount = hdr.ancount = hdr.nscount = hdr.arcount = 0;
+		make_hdr(&hdr,packet);
+		return packet;
+	}
+
+        qc = qd;
+        count = an + ns + ar;
+	offset = 12; /* Beginning of first question */
+	/* Jump past all of the questions */
+        while(qc > 0) {
+		int len;
+		len = dlabel_length(packet,offset);
+		if(len == JS_ERROR) {
+			hdr.tc = 1;
+		        hdr.qdcount = hdr.ancount = hdr.nscount = 
+				hdr.arcount = 0;
+			make_hdr(&hdr,packet);
+			return packet;
+		}
+		len += 4; /* Type and class */
+		offset += len;
+		if(offset >= packet->unit_count) {
+			hdr.tc = 1;
+		        hdr.qdcount = hdr.ancount = hdr.nscount = 
+				hdr.arcount = 0;
+			make_hdr(&hdr,packet);
+			return packet;
+		}
+		qc--;
+	}
+
+	/* Jump past all of the answers except for the last one */	
+	while(count > 1) {
+		int len;
+		len = dlabel_length(packet,offset);
+		if(len == JS_ERROR) {
+			hdr.tc = 1;
+		        hdr.qdcount = hdr.ancount = hdr.nscount = 
+				hdr.arcount = 0;
+			make_hdr(&hdr,packet);
+			return packet;
+		}
+		len += 8; /* type, class, TTL, and RDLENGTH */
+		offset += len;
+		if(offset + 2 >= packet->unit_count) {
+			hdr.tc = 1;
+		        hdr.qdcount = hdr.ancount = hdr.nscount = 
+				hdr.arcount = 0;
+			make_hdr(&hdr,packet);
+			return packet;
+		}
+		/* Get len from the rdlength of the data (this is why the 
+                 * packet *must* be uncompressed) */
+		len = (((*(packet->string + offset ) & 0xff) << 8) +
+		      *(packet->string + offset + 1));
+	        offset += len + 2;
+		if(offset >= packet->unit_count) {
+			hdr.tc = 1;
+		        hdr.qdcount = hdr.ancount = hdr.nscount = 
+				hdr.arcount = 0;
+			make_hdr(&hdr,packet);
+			return packet;
+		}
+		count--;
+	}
+			
+	/* Now that we've found the last DNS data, remove it from the 
+         * packet */
+	if(ar > 0) { 
+		ar--; 
+		hdr.arcount = ar; 
+	} else if(ns > 0) { 
+		ns--; 
+		hdr.nscount = ns;
+	} else {		
+		hdr.tc = 1;
+		hdr.qdcount = hdr.ancount = hdr.nscount = hdr.arcount = 0;
+		make_hdr(&hdr,packet);
+		return packet;
+	}
+
+	hdr.tc = 0;
+	make_hdr(&hdr,packet);
+	packet->unit_count = offset;
+	return packet;
+
+}
+		
