@@ -1,4 +1,4 @@
-/* Copyright (c) 2002 Sam Trenholme
+/* Copyright (c) 2002-2006 Sam Trenholme
  *
  * TERMS
  *
@@ -185,3 +185,18 @@ int read_ns(js_string *in, js_string *out, int offset);
    Output: JS_ERROR on error, byes in TXT record on success
 */
 int read_txt(js_string *in, js_string *out, int offset);
+
+/* This function is designed to make a packet which compresses to a size
+ * greater than 512 bytes smaller.  The input is an uncompressed DNS packet;
+ * the output is the same packet with the last DNS record removed from the
+ * packet.  As per RFC2181 §9, if we are removing a DNS record from the NS
+ * or AN section of a reply, the TC bit is not set.  Otherwise (as a 
+ * reasonable interpretation of the wishes in RFC2181 §9), we remove all DNS
+ * information except the header and mark the DNS packet truncated. 
+ *
+ * Input: A js_string object with a full uncompressed raw DNS packet.
+ * 
+ * Output: A point to the above js_string object on success; 0 on error */
+
+js_string *squeeze_to_fit(js_string *packet);
+
