@@ -1,11 +1,30 @@
-/* Public domain 2001 by Sam Trenholme */
+/* Copyright (c) 2002,2003 Sam Trenholme
+ *
+ * TERMS
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
+ * are met:
+ *
+ * 1. Redistributions of source code must retain the above copyright
+ *    notice, this list of conditions and the following disclaimer.
+ * 2. Redistributions in binary form must reproduce the above copyright
+ *    notice, this list of conditions and the following disclaimer in the
+ *    documentation and/or other materials provided with the distribution.
+ *
+ * This software is provided 'as is' with no guarantees of correctness or
+ * fitness for purpose.
+ */
+
+
 /* This tests the parsing of the ParseMaraRc routines */
 
 #include "../libs/MaraHash.h"
 #include "../MaraDns.h"
 #include <stdio.h>
 
-extern int parseline();
+extern int parseline(js_string *line, js_string *var, js_string *key,
+		js_string *value, int *do_plus);
 
 int main() {
         js_string *line, *v1, *v2, *v3;
@@ -26,7 +45,8 @@ int main() {
                 js_buf_getline(f,line);
                 printf("\nLine: ");
                 js_show_stdout(line);
-                printf("%s%d%s","Parse value: ",parseline(line,v1,v2,v3),"\n");
+                printf("%s%d%s","Parse value: ",parseline(line,v1,v2,v3,0),
+				"\n");
                 printf("Variable: ");
                 js_show_stdout(v1);
                 printf("\nKey: ");
